@@ -4,6 +4,7 @@ import asyncio
 from copy import deepcopy
 from datetime import UTC, datetime
 import json
+import logging
 from typing import Any
 from unittest.mock import AsyncMock, patch
 
@@ -2565,10 +2566,14 @@ async def test_abort_health_check(multisensor_6: node_pkg.Node, uuid4, mock_comm
     }
 
 
-async def test_unknown_event(multisensor_6: node_pkg.Node):
-    """Test that an unknown event type causes an exception."""
-    with pytest.raises(KeyError):
-        assert multisensor_6.receive_event(Event("unknown_event", {"source": "node"}))
+async def test_unknown_event(multisensor_6: node_pkg.Node, caplog):
+    """Test that an unknown event type logs a message but does not raise."""
+    caplog.set_level(logging.INFO)
+    event = Event("unknown_event", {"source": "node", "event": "unknown_event"})
+    multisensor_6.receive_event(event)
+    assert len(caplog.records) == 1
+    assert "Unhandled node event: unknown_event" in caplog.records[0].message
+    assert caplog.records[0].levelno == logging.INFO
 
 
 async def test_default_volume(multisensor_6: node_pkg.Node, uuid4, mock_command):
@@ -2786,3 +2791,17 @@ async def test_supervision_result_invalid(
 
     with pytest.raises(ValueError):
         await node.async_set_raw_config_parameter_value(1, 1)
+
+
+async def test_node_info_received_event(multisensor_6: node_pkg.Node):
+    """Test that the node info received event is successfully validated by pydantic."""
+    node = multisensor_6
+    event_type = "node info received"
+    event_data = {"source": "node", "event": event_type, "nodeId": node.node_id}
+    event = Event(event_type, event_data)
+
+    def callback(data: dict) -> None:
+        assert data == event_data
+
+    node.on(event_type, callback)
+    node.receive_event(event)
