@@ -4,6 +4,7 @@ Constants for the Thermostat CCs.
 Includes Thermostat Fan Mode, Thermostat Fan State, Thermostat Mode, Thermostat
 Operating State, Thermostat Setback, and Thermostat Setpoint CCs.
 """
+
 from __future__ import annotations
 
 from enum import IntEnum
@@ -59,11 +60,7 @@ class ThermostatOperatingState(IntEnum):
 
 
 class ThermostatSetpointType(IntEnum):
-    """
-    Enum with all (known/used) Z-Wave Thermostat Setpoint Types.
-
-    Returns tuple of (property_key, property_key_name).
-    """
+    """Enum with all (known/used) Z-Wave Thermostat Setpoint Types."""
 
     # https://github.com/zwave-js/node-zwave-js/blob/master/packages/zwave-js/src/lib/commandclass/ThermostatSetpointCC.ts#L53-L66
     NA = 0
@@ -80,16 +77,6 @@ class ThermostatSetpointType(IntEnum):
     FULL_POWER = 15
 
 
-# In Z-Wave the modes and presets are both in ThermostatMode.
-# This list contains thermostat modes we should consider a mode only
-THERMOSTAT_MODES = [
-    ThermostatMode.OFF,
-    ThermostatMode.HEAT,
-    ThermostatMode.COOL,
-    ThermostatMode.AUTO,
-    ThermostatMode.AUTO_CHANGE_OVER,
-]
-
 THERMOSTAT_MODE_SETPOINT_MAP: dict[int, list[ThermostatSetpointType]] = {
     ThermostatMode.OFF: [],
     ThermostatMode.HEAT: [ThermostatSetpointType.HEATING],
