@@ -3,6 +3,7 @@
 from __future__ import annotations
 
 from dataclasses import dataclass
+import logging
 from typing import TYPE_CHECKING, Any, Literal, cast
 
 from zwave_js_server.model.node.firmware import NodeFirmwareUpdateInfo
@@ -46,17 +47,20 @@ from .statistics import (
 if TYPE_CHECKING:
     from ...client import Client
 
+_LOGGER = logging.getLogger(__package__)
 
-DEFAULT_CONTROLLER_STATISTICS = ControllerStatisticsDataType(
-    messagesTX=0,
-    messagesRX=0,
-    messagesDroppedTX=0,
-    messagesDroppedRX=0,
-    NAK=0,
-    CAN=0,
-    timeoutACK=0,
-    timeoutResponse=0,
-    timeoutCallback=0,
+DEFAULT_CONTROLLER_STATISTICS = (  # pylint: disable=invalid-name
+    ControllerStatisticsDataType(
+        messagesTX=0,
+        messagesRX=0,
+        messagesDroppedTX=0,
+        messagesDroppedRX=0,
+        NAK=0,
+        CAN=0,
+        timeoutACK=0,
+        timeoutResponse=0,
+        timeoutCallback=0,
+    )
 )
 
 
@@ -901,12 +905,15 @@ class Controller(EventBase):
                 f"{event.data}"
             )
 
-        CONTROLLER_EVENT_MODEL_MAP[event.type].from_dict(event.data)
+        if (event_type := event.type) not in CONTROLLER_EVENT_MODEL_MAP:
+            _LOGGER.info("Unhandled controller event: %s", event_type)
+            return
 
+        CONTROLLER_EVENT_MODEL_MAP[event_type].from_dict(event.data)
         self._handle_event_protocol(event)
 
         event.data["controller"] = self
-        self.emit(event.type, event.data)
+        self.emit(event_type, event.data)
 
     def handle_inclusion_failed(self, event: Event) -> None:
         """Process an inclusion failed event."""
