@@ -73,7 +73,7 @@ if TYPE_CHECKING:
 # pylint: disable=too-many-lines
 _LOGGER = logging.getLogger(__package__)
 
-DEFAULT_NODE_STATISTICS = NodeStatisticsDataType(
+DEFAULT_NODE_STATISTICS = NodeStatisticsDataType(  # pylint: disable=invalid-name
     commandsTX=0,
     commandsRX=0,
     commandsDroppedTX=0,
@@ -475,12 +475,15 @@ class Node(EventBase):
 
     def receive_event(self, event: Event) -> None:
         """Receive an event."""
-        NODE_EVENT_MODEL_MAP[event.type].from_dict(event.data)
+        if (event_type := event.type) not in NODE_EVENT_MODEL_MAP:
+            _LOGGER.info("Unhandled node event: %s", event_type)
+            return
 
+        NODE_EVENT_MODEL_MAP[event_type].from_dict(event.data)
         self._handle_event_protocol(event)
         event.data["node"] = self
 
-        self.emit(event.type, event.data)
+        self.emit(event_type, event.data)
 
     async def async_send_command(
         self,
@@ -1123,6 +1126,10 @@ class Node(EventBase):
                     "Unhandled notification command class: %s", command_class.name
                 )
 
+    def handle_node_info_received(self, event: Event) -> None:
+        """Process a node info received event."""
+        # Nothing to do for now
+
     def handle_firmware_update_progress(self, event: Event) -> None:
         """Process a node firmware update progress event."""
         self._firmware_update_progress = event.data["firmware_update_progress"] = (
