@@ -1,4 +1,5 @@
 """Multilevel Sensor Command Class specific utility functions for values."""
+
 from __future__ import annotations
 
 from ...const import CommandClass
@@ -20,9 +21,9 @@ def get_multilevel_sensor_type(value: Value) -> MultilevelSensorType:
     try:
         return MultilevelSensorType(value.metadata.cc_specific[CC_SPECIFIC_SENSOR_TYPE])
     except ValueError:
-        raise UnknownValueData(  # pylint: disable=raise-missing-from
+        raise UnknownValueData(
             value, f"metadata.cc_specific.{CC_SPECIFIC_SENSOR_TYPE}"
-        )
+        ) from None
 
 
 def get_multilevel_sensor_scale_type(value: Value) -> MultilevelSensorScaleType:
@@ -32,6 +33,6 @@ def get_multilevel_sensor_scale_type(value: Value) -> MultilevelSensorScaleType:
     try:
         return scale_enum(value.metadata.cc_specific[CC_SPECIFIC_SCALE])
     except ValueError:
-        raise UnknownValueData(  # pylint: disable=raise-missing-from
+        raise UnknownValueData(
             value, f"metadata.cc_specific.{CC_SPECIFIC_SCALE}"
-        )
+        ) from None
